@@ -10,6 +10,8 @@ import pprint
 import re
 import select
 import sys
+import time
+from datetime import datetime, timedelta
 
 import click
 import psycopg2
@@ -32,7 +34,7 @@ from .exc import RDSError, SuperUserError
 from .node import traverse_breadth_first, traverse_post_order, Tree
 from .querybuilder import QueryBuilder
 from .redisqueue import RedisQueue
-from .settings import POLL_TIMEOUT
+from .settings import POLL_TIMEOUT, REPLICATION_SLOT_CLEANUP_INTERVAL
 from .utils import (
     get_config,
     get_private_keys,
@@ -65,10 +67,12 @@ class Sync(Base):
         self.es = ElasticHelper()
         self.__name = f"{self.database}_{self.index}"
         self._checkpoint = None
+        self._truncate = False
         self.verbose = verbose
         self._checkpoint_file = f".{self.__name}"
         self.redis = RedisQueue(self.__name)
         self.tree = Tree(self)
+        self._last_truncate_timestamp = datetime.now()
         if validate:
             self.validate()
             self.create_setting()
@@ -658,8 +662,8 @@ class Sync(Base):
                         sa.cast(
                             sa.cast(
                                 node.model.c.xmin,
-                                sa.Text
-                            ), sa.BigInteger
+                                sa.Text,
+                            ), sa.BigInteger,
                         ) >= txmin
                     )
                 if txmax:
@@ -667,8 +671,8 @@ class Sync(Base):
                         sa.cast(
                             sa.cast(
                                 node.model.c.xmin,
-                                sa.Text
-                            ), sa.BigInteger
+                                sa.Text,
+                            ), sa.BigInteger,
                         ) < txmax
                     )
 
@@ -874,11 +878,26 @@ class Sync(Base):
         """Pull data from db."""
         txmin = self.checkpoint
         txmax = self.txid_current
-        logger.debug(f'pull txmin {txmin}; txmax {txmax}')
+        logger.debug(f'pull txmin: {txmin} txmax: {txmax}')
         # forward pass sync
         self.sync(txmin=txmin, txmax=txmax)
         # now sync up to txmax to capture everything we might have missed
         self.logical_slot_changes(txmin=txmin, txmax=txmax)
+        self._truncate = True
+
+    @threaded
+    def truncate_slots(self):
+        """Truncate the logical replication slot."""
+        while True:
+            if self._truncate and (
+                datetime.now() >= self._last_truncate_timestamp + timedelta(
+                    seconds=REPLICATION_SLOT_CLEANUP_INTERVAL
+                )
+            ):
+                logger.debug(f'Truncating replication slot: {self.__name}')
+                self.logical_slot_get_changes(self.__name, upto_nchanges=None)
+                self._last_truncate_timestamp = datetime.now()
+            time.sleep(0.1)
 
     def receive(self):
         """
@@ -901,6 +920,9 @@ class Sync(Base):
         # poll Redis and populate Elasticsearch
         self.poll_redis()
 
+        # start a background worker thread to cleanup the replication slot
+        self.truncate_slots()
+
 
 @click.command()
 @click.option(
